﻿using System;
using CoreGraphics;
using Foundation;
using Syncfusion.SfChart.iOS;
using UIKit;

namespace DataPointClick
{
	public partial class ViewController : UIViewController
	{
		protected ViewController(IntPtr handle) : base(handle)
		{
			// Note: this .ctor should not contain any initialization logic.
		}

		public override void ViewDidLoad()
		{
			base.ViewDidLoad();
			SFChart chart = new SFChart();
			chart.EdgeInsets = new UIEdgeInsets(25, 10, 10, 10);
			chart.Frame = new CGRect(0, 0, this.View.Frame.Width, this.View.Frame.Height - 10);

			SFCategoryAxis primaryAxis = new SFCategoryAxis();
			chart.PrimaryAxis = primaryAxis;

			SFNumericalAxis secondaryAxis = new SFNumericalAxis();
			secondaryAxis.Maximum = NSObject.FromObject(70);
			chart.SecondaryAxis = secondaryAxis;

			ChartDataModel dataModel = new ChartDataModel();
			chart.DataSource = dataModel as SFChartDataSource;
			chart.Delegate = new ChartDelegate(this.View);
			this.View.AddSubview(chart);
		}

		public override void DidReceiveMemoryWarning()
		{
			base.DidReceiveMemoryWarning();
			// Release any cached data, images, etc that aren't in use.
		}
	}

	public class ChartDelegate : SFChartDelegate
	{
		public UIView MainView { get; set; }

		public ChartDelegate(UIView view)
		{
			MainView = view;
		}

		public override void WillDataPointSelect(SFChart chart, SFChartSelectionChangingInfo info)
		{
			chart.RemoveFromSuperview();
			UILabel labelValue = new UILabel();
			labelValue.Frame = new CGRect(20, 30, MainView.Frame.Size.Width, 30);
			labelValue.Text = "SelectedDataPointIndex: " + info.SelectedDataPointIndex.ToString();
			MainView.AddSubview(labelValue);
		}

	}

	public class ChartDataModel : SFChartDataSource
	{
		NSMutableArray DataPoints;

		public ChartDataModel()
		{
			DataPoints = new NSMutableArray();
			DataPoints.Add(new SFChartDataPoint(NSObject.FromObject("USA"), NSObject.FromObject(45)));
			DataPoints.Add(new SFChartDataPoint(NSObject.FromObject("China"), NSObject.FromObject(52)));
			DataPoints.Add(new SFChartDataPoint(NSObject.FromObject("Japan"), NSObject.FromObject(48)));
			DataPoints.Add(new SFChartDataPoint(NSObject.FromObject("Australia"), NSObject.FromObject(57)));
			DataPoints.Add(new SFChartDataPoint(NSObject.FromObject("France"), NSObject.FromObject(64)));
		}

		public override nint NumberOfSeriesInChart(SFChart chart)
		{
			return 1;
		}

		public override SFSeries GetSeries(SFChart chart, nint index)
		{
			SFColumnSeries series = new SFColumnSeries();
			series.DataMarker.ShowLabel = true;
			series.EnableDataPointSelection = true;
			return series;
		}

		public override SFChartDataPoint GetDataPoint(SFChart chart, nint index, nint seriesIndex)
		{
			return DataPoints.GetItem<SFChartDataPoint>((nuint)index);
		}

		public override nint GetNumberOfDataPoints(SFChart chart, nint index)
		{
			return (nint)DataPoints.Count;
		}
	}
}

